@@ -3,7 +3,7 @@ import logging
 import functools
 
 import bizerror
-from fastutils.funcutils import get_inject_params
+from fastutils.funcutils import call_with_inject
 from fastutils.typingutils import Number
 from fastutils.typingutils import smart_cast
 from django.http import JsonResponse
@@ -14,7 +14,11 @@ from .pack import SimpleJsonResultPacker
 
 logger = logging.getLogger(__name__)
 
-simple_json_result_packer = SimpleJsonResultPacker()
+simple_result_packer = SimpleJsonResultPacker()
+
+def setup_result_packer(packer):
+    global simple_result_packer
+    simple_result_packer = packer
 
 class View(object):
     """Process class of apiview.
@@ -32,24 +36,31 @@ class View(object):
             if not str(error).endswith("got an unexpected keyword argument '_django_apiview_view_instance'"):
                 raise error
             else:
-                params = get_inject_params(func, self.data)
-                return func(**params)
+                return call_with_inject(func, self.data)
 
-def apiview(func):
-    """Turn the view function into apiview function. Must use as the first decorator.
-    """
-    def wrapper(request, **kwargs):
-        view = View(request,**kwargs)
-        package = {}
-        try:
-            result = view.process(func)
-            package = simple_json_result_packer.pack_result(result)
-        except Exception as error:
-            logger.exception("apiview process failed: {}".format(str(error)))
-            package = simple_json_result_packer.pack_error(error)
-        return JsonResponse(package, encoder=SimpleJsonEncoder, json_dumps_params={"ensure_ascii": False, "allow_nan": True, "sort_keys": True})
-    wrapper.csrf_exempt = True
-    return functools.wraps(func)(wrapper)
+class Apiview(object):
+    def __init__(self, packer):
+        self.packer = packer
+    
+    def __call__(self, func):
+        """Turn the view function into apiview function. Must use as the first decorator.
+        """
+        def wrapper(request, **kwargs):
+            view = View(request,**kwargs)
+            package = {}
+            try:
+                result = view.process(func)
+                package = self.packer.pack_result(result)
+            except Exception as error:
+                logger.exception("apiview process failed: {}".format(str(error)))
+                if not isinstance(error, bizerror.BizError):
+                    error = bizerror.BizError(error)
+                package = self.packer.pack_error(error)
+            return JsonResponse(package, encoder=SimpleJsonEncoder, json_dumps_params={"ensure_ascii": False, "allow_nan": True, "sort_keys": True})
+        wrapper.csrf_exempt = True
+        return functools.wraps(func)(wrapper)
+
+apiview = Apiview(simple_result_packer)
 
 def requires(*parameter_names):
     """Throw bizerror.MissingParameter exception if required parameters not given.
